@@ -5,9 +5,11 @@ from neuroio.api.base import APIBase, APIBaseAsync
 
 class Whoami(APIBase):
     def me(self) -> Response:
-        return self.client.get(url="/v1/whoami/")
+        with self.get_client() as client:
+            return client.get(url="/v1/whoami/")
 
 
 class WhoamiAsync(APIBaseAsync):
     async def me(self) -> Response:
-        return await self.client.get(url="/v1/whoami/")
+        async with self.get_client() as client:
+            return await client.get(url="/v1/whoami/")
